@@ -16,6 +16,9 @@
     (autoload 'run-picolisp "inferior-picolisp")
     (autoload 'picolisp-mode "picolisp"
       "Major mode for editing picolisp files." t)
-    (setq picolisp-program-name "/usr/lib/picolisp/bin/plmod")
-    (add-to-list 'auto-mode-alist '("\\.l\\'" . picolisp-mode))))
+    (add-to-list 'auto-mode-alist '("\\.l\\'" . picolisp-mode))
+    (autoload 'picolisp-wiki-mode "picolisp-wiki-mode"
+      "Major mode for editing Picolisp-Wiki files" t)
+    (setq auto-mode-alist
+          (cons '("\\.plw" . picolisp-wiki-mode) auto-mode-alist))))
 
